OC.L10N.register(
    "core",
    {
    "Please select a file." : "請選擇檔案。",
    "File is too big" : "檔案太大",
    "The selected file is not an image." : "選擇的檔案不是圖像檔案。",
    "The selected file cannot be read." : "選擇的檔案無法讀取。",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 參數的設定",
    "The file was only partially uploaded" : "檔案僅部分上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "寫入硬碟失敗",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "Invalid file provided" : "提供的檔案無效",
    "No image or file provided" : "未提供圖像或檔案",
    "Unknown filetype" : "未知的檔案類型",
    "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
    "Invalid image" : "圖像無效",
    "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
    "No crop data provided" : "未設定剪裁",
    "No valid crop data provided" : "未提供有效的剪裁設定",
    "Crop is not square" : "剪裁設定不是正方形",
    "State token does not match" : "狀態權杖不相符",
    "Invalid app password" : "無效的應用程式密碼",
    "Could not complete login" : "無法完成登錄",
    "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "不支援 Nextcloud 的這個社群版本，且推播通知有所限制。",
    "Login" : "登入",
    "Password reset is disabled" : "密碼重設已停用",
    "Could not reset password because the token is expired" : "權杖已過期，無法重設密碼",
    "Could not reset password because the token is invalid" : "重設密碼權杖無效，重設失敗",
    "%s password reset" : "%s 密碼重設",
    "Password reset" : "密碼重設",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。若您沒有要求重設密碼，請不用理會此電子郵件。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點取下方的連結以重設您的密碼。如果您沒有要求重設密碼的話，請不用理會此電子郵件。",
    "Reset your password" : "重設密碼",
    "Nextcloud Server" : "Nextcloud 伺服器",
    "Some of your link shares have been removed" : "部分分享連結己被移除",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
    "The user limit of this instance is reached." : "的達此實例的用戶上限。",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "請輸入你獲得的訂閱代碼以解開用戶數量限制。有關Nextcloud企業版的詳細信息請參見我們的網站。",
    "Preparing update" : "準備更新",
    "[%d / %d]: %s" : "[%d / %d]： %s",
    "Repair step:" : "修復步驟：",
    "Repair info:" : "修復資訊：",
    "Repair warning:" : "修復警告：",
    "Repair error:" : "修復錯誤：",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列（command line）更新系統。",
    "Turned on maintenance mode" : "啟用維護模式",
    "Turned off maintenance mode" : "停用維護模式",
    "Maintenance mode is kept active" : "伺服器正處於維護模式",
    "Updating database schema" : "正在更新數據庫模式",
    "Updated database" : "已更新數據庫",
    "Update app \"%s\" from App Store" : "從 App Store 更新應用程式 “%s”",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "檢查 %s 是否有可更新的數據庫模式（若數據庫較大，可能需要一段時間）",
    "Updated \"%1$s\" to %2$s" : "已從 %1$s 更新至 %2$s",
    "Set log level to debug" : "設定記錄至除錯層級",
    "Reset log level" : "重設記錄層級",
    "Starting code integrity check" : "開始檢查程式碼完整性",
    "Finished code integrity check" : "已完成程式碼完整性檢查",
    "%s (incompatible)" : "%s （不相容）",
    "The following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
    "Already up to date" : "此版本為最新版本",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 界面似乎為故障狀態，導致您的網頁伺服器無法提供檔案同步功能。",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的網絡伺服器未正確設置為解析“ {url}”。可以在 {linkstart} 說明書↗{linkend} 中找到更多信息。",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的網絡伺服器未正確設置為解析“ {url}”。這很可能與未更新為直接傳送此資料夾的Web伺服器配置有關。請將您的配置與Apache的“。htaccess”中提供的重寫規則或Nginx文檔中提供的重寫規則（位於{linkstart}文檔頁面↗{linkend}）進行比較。在Nginx上，通常以“ location ~”開頭的行需要更新。",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "您的 Web 伺服器未正確設置為傳遞 .woff2 檔案。這通常是 Nginx 配置的問題。對於Nextcloud 15，需要進行調整以同時交付 .woff2 檔案。將您的 Nginx 配置與我們的{linkstart}文檔↗{linkend}中的推薦配置進行比較。",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 設定似乎不完整，導致無法正確取得系統環境變數，因為偵測到 getenv(\"PATH\") 回傳資料為空值",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "請查看 {linkstart}安裝文檔↗{linkend}，以獲取PHP配置說明和伺服器的PHP配置，尤其是在使用 php-fpm 時。",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "「唯讀設定檔」已經啟用，這樣可以防止來自網頁端的設定操作，每次需要更改設定時，都需要手動將設定檔暫時改為可讀寫。",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "您尚未設置或驗證您的電郵伺服器配置。請前往 {mailSettingsStart} 基本設置 {mailSettingsEnd} 進行設置。然後使用表單下方的【發送電郵】按鈕驗證您的設置。",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "您的數據庫並未使用 \"READ COMMITTED\" 的交易隔離等級。當有多個操作平行進行時，這可能會造成問題。",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未偵測到 PHP 模組 'fileinfo'。強烈建議啟用這個模組，以取得最好的 MIME 檔案類型偵測支援。",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "交易性檔案上鎖已停用，這可能導致爭用條件問題。在config.php中啟用 “filelocking.enabled” 可以避免這些問題。有關更多信息，請參見{linkstart}文檔↗{linkend}。",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "請確保將 config.php 文件中的“overwrite.cli.url”選項設置為您的用戶主要用於訪問此 Nextcloud 的 URL。建議：“{suggestedOverwriteCliURL}”。否則，通過 cron 生成的 URL 可能會出現問題。（但是，建議的 URL 可能不是您的用戶主要用於訪問此 Nextcloud 的 URL。最好是仔細檢查以防萬一。）",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "你並未設置手機國際冠碼。設置後用戶在個人檔案設定手機號碼時不必再輸入國際冠碼。若要這樣做，請新增「default_phone_region」於設定檔，允許的國家及地區請參閱 {linkstart}ISO 3166-1 code ↗{linkend} 清單。",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : " 無法透過 CLI 來執行排程工作，發生以下技術性錯誤：",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "最後一次後台作業執行了{relativeTime}。似乎有問題。{linkstart}檢查後台作業設置↗{linkend}。",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被限制，以避免我們的免費服務負載過重。請至 {linkstart}nextcloud.com/enterprise{linkend} 取得更多關於 Nextcloud 企業版的資訊。",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此伺服器沒有可用的互聯網連接（無法訪問多個端點）。 這意味著某些功能（例如掛載外部存儲、有關更新或安裝第三方應用程式的通知）將無法使用。 遠端存取檔案和發送通知電子郵件也可能不起作用。 請建立從此伺服器到互聯網的連接以享受所有功能。",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "尚未配置內存緩存。為了提高性能，請配置內存緩存（如有）。可以在 {linkstart}說明書↗{linkend} 中找到更多資訊。",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "由於安全原因，強烈建議不要使用PHP找到適合隨機性的來源。可以在{linkstart}文檔↗{linkend}中找到更多信息。",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您當前正在運行PHP {version}。只要您的發行版支持，請升級PHP版本以利用 {linkstart}PHP Group↗提供的性能和安全更新{linkend}。",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 是支援 PHP 7.3 的最後版本，Nextcloud 24 僅支援 PHP 7.4 以上的版本。",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "反向代理標頭（reverse proxy header）配置不正確，或者您正在從受信任的代理（trusted proxy）存取 Nextcloud。如果不是這樣，則這是一個安全問題，並且可以使攻擊者欺騙其對 Nextcloud 可見的IP地址。可以在{linkstart}文檔↗{linkend}中找到更多資訊。",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached 配置為分布式緩存，但是安裝了錯誤的PHP模塊 “memcache”。\\OC\\Memcache\\Memcached 僅支持 “memcached”，不支持 “memcache”。有關這兩個模塊的信息，請參見{linkstart}內存緩存wiki {linkend}。",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "某些檔案未通過完整性檢查。有關如何解決此問題的更多信息，請參見{linkstart1}文檔↗{linkend}。（{linkstart2}無效檔案清單…{linkend} / {linkstart3}重新掃描…{linkend}）",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache 模塊配置不正確。 請參閱 {linkstart} 文檔 ↗{linkend} 了解更多信息。",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "無法取得 PHP 中的 \"set_time_limit\" 函式。這可能導致執行過程被終止並造成不完整安裝。我們強烈建議啟用該函式。",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "您的 PHP 並未啟用 FreeType 支援，導致大頭貼產生器和設定界面無法使用。",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "在資料表 \"{tableName}\" 中，找不到索引值 \"{indexName}\" 。",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "數據庫缺少某些索引值。由於將索引添加到大型數據庫表可能需要一段時間，安裝程序因此不會自動添加索引。您可執行 “occ db:add-missing-indices” 來手動新增那些缺少的索引值。當索引值新增完成後，查詢的速度通常會變得快許多",
    "Missing primary key on table \"{tableName}\"." : "數據表 \"{tableName}\" 缺少主鍵。",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "數據庫缺少一些主鍵。由於在大表上添加主鍵可能會花費一些時間，因此我們不會自動添加主鍵。通過運行 “occ db:add-missing-primary-keys”，可以在實例繼續運行的同時手動添加那些缺少的主鍵。",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "數據表 {tableName} 中缺少可選列 {columnName} 。",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "數據庫遺失了一些欄位，然而添加主鍵這個動作將在肥大的數據庫花費許多時間，故我們將不會自動處理這項問題。藉由執行「occ db:add-missing-columns」手動添加這些欄位將能在系統持續運作時修復這個問題。添加可選欄位將提高系統回應速度和可用性。",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "您的 Nextcloud 缺少了某些建議的 PHP 模組。為了提升效能與相容性，強烈建議您安裝這些 PHP 模組。",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "雖然已啟用佈景主題應用程式，但並未啟用 PHP 模組「imagick」。為了讓 favicon 產生流程正常運作，您必須安裝並啟用此模組。",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "未啟用 PHP 模組「gmp」與「bcmath」。若您要使用 WebAuthn 免密碼驗證，這些模組就是必要的。",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您好像正在運行 32 位 PHP 版本。Nextcloud 需要 64 位才能運行良好。請將您的操作系統和 PHP 升級到 64 位！有關更多詳細信息，請閱讀 {linkstart} 有關的說明書頁面 ↗{linkend}。",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "本系統安裝的 php-imagick 不支援 SVG，為了更好的相容性，建議安裝它。",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "數據庫中的某些列缺少對 big int 的轉換。由於更改大表上的列類型可能需要一些時間，因此無法自動更改它們。通過運行 “occ db：convert-filecache-bigint”，可以手動應用這些未決的更改。實例處於脫機狀態時需要執行此操作。有關更多詳細信息，請{linklink}關於此↗{linkend}的文檔頁面。",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "目前您的後端數據庫使用 SQLite，在大型服務當中，我們建議您使用其他的數據庫後端。",
    "This is particularly recommended when using the desktop client for file synchronisation." : "若您使用電腦客戶端來同步檔案，非常建議您這麼做。",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "要遷移到另一個數據庫，請使用指令工具：“ occ db：convert-type”，或參閱 {linkstart} 說明書↗{linkend}。",
    "The PHP memory limit is below the recommended value of 512MB." : "目前的 PHP 的記憶體限制設定低於建議值 512MB",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "某些應用程式的資料夾所有者與網頁伺服器預設用戶不同。這可能是因為您手動安裝了這些應用程式。請檢查以下應用程式資料夾的相關權限：",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL 用作數據庫，但不支持4-byte字符。為了能夠處理4字節字符（如表情符號）而不會出現文件名或註釋問題，建議在MySQL中啟用4字節支持。有關更多詳細信息，請參見{linkstart}關於此↗的文檔頁面{linkend}。",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此站台使用Amazon S3物件儲存為主要儲存區。上傳檔案會暫存在伺服器，因此建議PHP的暫存資料夾最少要有50GB可用容量。請在登入檔中查閱關於資料夾路徑及可用容量的詳細資訊。要增進效能，請在php.ini中變更暫存資料夾位置，或將該資料夾容量增加。",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "此實例的臨時目錄指向一個不存在或不可寫的目錄。",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "您正在通過安全連接存取實例，但是您的實例正在生成不安全的URL。這很可能意味著您被隱藏在反向代理（reverse proxy）之後，並且覆蓋配置變量（overwrite config variables）未正確設置。請閱讀{linkstart}有關此的文檔頁面↗{linkend}。",
    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
    "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkedin}。",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取。這表示 .htaccess 設定檔並未生效。我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這將讓某些功能無法正常運作，我們建議修正此項設定。",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不包防 \"{expected}\" ，這是一個潛在的安全性和隱私風險，建議調整此項設定。",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP header “{header}” 未設置為 “ {val1}”、“ {val2}”、“{val3}”、“{val4}” 或 “{val5}”。這可能會洩漏引用資訊。請參閱 {linkstart}W3C建議↗{linkend}。",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "未將 “Strict-Transport-Security” HTTP header 設置為至少“{seconds}”秒。為了增強安全性，建議按照{linkstart}安全提示↗{linkend}中的說明啟用 HSTS。",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "通過HTTP不安全地存取站點。強烈建議您將伺服器設置改為要求HTTPS，如{linkstart}安全提示↗{linkend}中所述。",
    "unknown text" : "文字不詳",
    "Hello world!" : "哈囉，世界！",
    "sunny" : "晴朗的",
    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今日天氣 {weather}",
    "Hello {name}" : "哈囉 {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告（1）</script></strong>",
    "new" : "新",
    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
    "Update to {version}" : "更新到 {version}",
    "An error occurred." : "發生錯誤。",
    "Please reload the page." : "請重新整理頁面。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗，檢視<a href=\"{url}\">論壇上的文章</a>來瞭解更多。",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
    "Continue to {productName}" : "前往 {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
    "More apps" : "更多應用程式",
    "Currently open" : "目前開啟",
    "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
    "Log in" : "登入",
    "Logging in …" : "正在登入…",
    "Server side authentication failed!" : "伺服器端認證失敗！",
    "Please contact your administrator." : "請聯絡系統管理員。",
    "An internal error occurred." : "發生內部錯誤",
    "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
    "Account name or email" : "賬戶名稱或電郵地址",
    "Password" : "密碼",
    "Wrong username or password." : "錯誤的用戶名稱 或 密碼",
    "User disabled" : "用戶已遭停用",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效，下一次登入將會被延時 30 秒。",
    "Username or email" : "用戶名稱 或 電郵地址",
    "Your account is not setup for passwordless login." : "你的賬號尚未設定免密碼登入。",
    "Browser not supported" : "不支持該瀏覽器",
    "Passwordless authentication is not supported in your browser." : "你使用的瀏覽器不支援無密碼身分驗證。",
    "Your connection is not secure" : "您的連線不安全",
    "Passwordless authentication is only available over a secure connection." : "無密碼身分驗證僅支援經加密的連線。",
    "Reset password" : "重設密碼",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
    "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼電郵。請聯絡您的管理員。",
    "Password cannot be changed. Please contact your administrator." : "無法重設密碼，請聯絡管理員。",
    "Back to login" : "回到登入畫面",
    "New password" : "新密碼",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請與管理員聯繫。確定要繼續嗎？",
    "I know what I'm doing" : "我知道我在做什麼",
    "Resetting password" : "重設密碼",
    "Recommended apps" : "推薦的應用程式",
    "Loading apps …" : "正在載入應用程式…",
    "Could not fetch list of apps from the App Store." : "無法從應用程式商店抓取應用程式清單。",
    "Installing apps …" : "正在安裝應用程式…",
    "App download or installation failed" : "應用程式下載或是安裝失敗",
    "Cannot install this app because it is not compatible" : "應用程式無法安裝，因為不相容",
    "Cannot install this app" : "無法安裝此應用程式",
    "Skip" : "略過",
    "Install recommended apps" : "安裝推薦的應用程式",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
    "Collaboratively edit office documents." : "協助編輯官方文件。",
    "Local document editing back-end used by the Collabora Online app." : "本地文件編輯後端由Collabora Online app提供。",
    "Forgot password?" : "忘記密碼？",
    "Log in with a device" : "使用免密碼裝置登入",
    "Back" : "返回",
    "Login form is disabled." : "登入表格已停用",
    "Edit Profile" : "編輯個人設定",
    "The headline and about sections will show up here" : "標題與關於部份將在此顯示",
    "You have not added any info yet" : "您尚未新增任何資訊",
    "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
    "Error opening the user status modal, try hard refreshing the page" : "打開用戶狀態模式時出錯，請嘗試刷新頁面",
    "Search starts once you start typing" : "開始輸入後開始搜尋",
    "Reset search" : "重置搜尋",
    "Start search" : "開始搜尋",
    "Search for {name} only" : "只搜尋 {name}",
    "No results for {query}" : "{query} 查詢沒有結果",
    "Press enter to start searching" : "按 Enter 開始搜尋",
    "Start typing to search" : "輸入文字以檢索",
    "Loading more results …" : "正在載入更多結果...",
    "Load more results" : "載入更多結果",
    "Search" : "搜尋",
    "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
    "Search {types} …" : "搜尋 {types} 中 …",
    "Settings" : "設定",
    "Could not load your contacts" : "無法載入您的聯絡人",
    "Search contacts …" : "搜尋聯絡人…",
    "No contacts found" : "查無聯絡人",
    "Show all contacts …" : "顯示所有聯絡人…",
    "Install the Contacts app" : "安裝「通訊錄」應用程式",
    "Loading your contacts …" : "正在載入聯絡人…",
    "Looking for {term} …" : "正在搜尋 {term} …",
    "No" : "否",
    "Yes" : "是",
    "No files in here" : "此處沒有任何檔案",
    "New folder" : "新資料夾",
    "No more subfolders in here" : "沒有子資料夾",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "已修改",
    "\"{name}\" is an invalid file name." : "\"{name}\" 是無效的檔案名稱。",
    "File name cannot be empty." : "檔案名稱不能為空。",
    "\"/\" is not allowed inside a file name." : "不允許檔案名稱中出現 \"/\"。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
    "{newName} already exists" : "{newName} 已經存在",
    "Choose" : "選擇",
    "Copy" : "複製",
    "Move" : "移動",
    "Error loading file picker template: {error}" : "載入檔案選擇器模板時出錯： {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "載入訊息模板時出錯： {error}",
    "read-only" : "唯讀",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 個檔案相抵觸"],
    "One file conflict" : "一個檔案抵觸",
    "New Files" : "新檔案",
    "Already existing files" : "已經存在的檔案",
    "Which files do you want to keep?" : "您要保留哪一個檔案？",
    "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，被複製的那個檔案名稱後面會加上編號",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "(all selected)" : "（已全選）",
    "({count} selected)" : "（已選擇 {count} 項）",
    "Error loading file exists template" : "載入「已存在檔案」的模板時發生錯誤",
    "Show list view" : "顯示清單視圖",
    "Show grid view" : "顯示網格視圖",
    "Pending" : "待辦中",
    "Copy to {folder}" : "複製到 {folder}",
    "Move to {folder}" : "移動到 {folder}",
    "Saving …" : "儲存中 ...",
    "Authentication required" : "必須驗證",
    "This action requires you to confirm your password" : "此操作需要您再次確認密碼",
    "Confirm" : "確認",
    "Failed to authenticate, try again" : "驗證失敗，請再試一次",
    "seconds ago" : "幾秒前",
    "Connection to server lost" : "伺服器連線中斷",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
    "Add to a project" : "加到專案",
    "Show details" : "顯示細節",
    "Hide details" : "隱藏細節",
    "Rename project" : "重新命名專案",
    "Failed to rename the project" : "重新命名專案失敗",
    "Failed to create a project" : "建立專案失敗",
    "Failed to add the item to the project" : "新增項目至專案時失敗",
    "Connect items to a project to make them easier to find" : "將項目連結到專案以便尋找",
    "Type to search for existing projects" : "搜尋現有專案",
    "New in" : "新加入",
    "View changelog" : "檢視版本更新紀錄",
    "Very weak password" : "密碼安全性極弱",
    "Weak password" : "密碼安全性弱",
    "So-so password" : "密碼安全性普通",
    "Good password" : "密碼安全性佳",
    "Strong password" : "密碼強度極佳",
    "No action available" : "沒有可用的操作",
    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
    "restricted" : "受限",
    "invisible" : "隱藏",
    "Delete" : "刪除",
    "Rename" : "重新命名",
    "Collaborative tags" : "協作標籤",
    "No tags found" : "查無標籤",
    "Personal" : "個人",
    "Users" : "用戶",
    "Apps" : "應用程式",
    "Admin" : "管理",
    "Help" : "說明",
    "Access forbidden" : "存取被拒",
    "Profile not found" : "找不到個人資料",
    "The profile does not exist." : "個人資料不存在",
    "Back to %s" : "回到 %s",
    "File not found" : "找不到檔案",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "伺服器上找不到該文件，或許這個分享已經被刪除或是過期了？",
    "Too many requests" : "太多要求",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
    "Error" : "錯誤",
    "Previous" : "上一個",
    "Internal Server Error" : "內部伺服器錯誤",
    "The server was unable to complete your request." : "伺服器無法完成你的請求。",
    "If this happens again, please send the technical details below to the server administrator." : "如果此問題重複發生，請寄送技術資訊給管理員。",
    "More details can be found in the server log." : "伺服器記錄檔裡面有更多細節",
    "Technical details" : "技術細節",
    "Remote Address: %s" : "遠端位置：%s",
    "Request ID: %s" : "請求編號：%s",
    "Type: %s" : "類型：%s",
    "Code: %s" : "代碼：%s",
    "Message: %s" : "訊息：%s",
    "File: %s" : "檔案：%s",
    "Line: %s" : "行數：%s",
    "Trace" : "追蹤",
    "Security warning" : "安全性警示",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄可能可以從互聯網存取，因為 .htaccess 不起作用。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "有關如何正確配置伺服器的信息，請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明書</a>。",
    "Create an <strong>admin account</strong>" : "新增<strong>管理員賬號</strong>",
    "Username" : "用戶名稱",
    "Show password" : "顯示密碼",
    "Toggle password visibility" : "切換密碼可見性",
    "Storage & database" : "儲存空間和數據庫",
    "Data folder" : "資料儲存位置",
    "Configure the database" : "設定數據庫",
    "Only %s is available." : "僅 %s 可使用。",
    "Install and activate additional PHP modules to choose other database types." : "安裝並啟動相關 PHP 模組來使用其他種數據庫",
    "For more details check out the documentation." : "要取得更多細節資訊，請參閱說明書。",
    "Database user" : "數據庫用戶",
    "Database password" : "數據庫密碼",
    "Database name" : "數據庫名稱",
    "Database tablespace" : "數據庫資料表空間",
    "Database host" : "數據庫主機",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
    "Performance warning" : "效能警告",
    "You chose SQLite as database." : "您選擇了 SQLite 作為數據庫",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他數據庫後端。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
    "Install" : "安裝",
    "Installing …" : "正在安裝 …",
    "Need help?" : "需要協助嗎？",
    "See the documentation" : "閱讀說明文件",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "您似乎正在嘗試重新安裝您的Nextcloud。然而，檔案 CAN_INSTALL 並未在您的config目錄中。請在您的config目錄中建立 CAN_INSTALL檔以繼續。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "無法從您的 config 目錄中移除 CAN_INSTALL 檔案。請手動移除他。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "這個應用程式需要啟用 Javascript 才能正常運作，請{linkstart}啟用Javascript{linkend}然後重新整理頁面。",
    "Skip to main content" : "跳到主內容",
    "Skip to navigation of app" : "跳到應用程式導覽",
    "Get your own free account" : "取得免費賬號",
    "%s's homepage" : "%s 的主頁",
    "Contacts" : "聯絡人",
    "Contacts menu" : "聯絡人選單",
    "Open settings menu" : "公開設定選項單",
    "Confirm your password" : "確認密碼",
    "Connect to your account" : "連結您的賬號",
    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 賬號",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若你並未嘗試在新的裝置登入你的賬戶，有什麼人證在嘗試登入你的賬戶並存取你的個人資料。大多數情況你並不用作任何應對，但也可通知你的系統管理員。",
    "App token" : "應用程式權杖",
    "Grant access" : "允許存取",
    "Alternative log in using app token" : "使用應用程式權杖來登入",
    "Account access" : "賬戶存取",
    "Currently logged in as %1$s (%2$s)." : "目前以 %1$s (%2$s) 身份登入。",
    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 賬戶",
    "Account connected" : "賬戶已連結",
    "Your client should now be connected!" : "客戶端應該已完成連線",
    "You can close this window." : "可以關閉此視窗",
    "This share is password-protected" : "此分享受密碼保護",
    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。 請重試或重新申請。",
    "Please type in your email address to request a temporary password" : "請輸入您的電郵地址以申請臨時密碼",
    "Email address" : "電郵地址",
    "Password sent!" : "密碼已傳送！",
    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
    "Go to %s" : "前往 %s",
    "Two-factor authentication" : "雙重認證",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的賬號已啟用進階安全機制，請選擇一個雙重認證方法：",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何已啟用的雙重認證方法，請聯絡管理員。",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "雙重認證已實施，但尚未在您的賬戶上對其進行配置。請聯絡管理員。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "雙重認證已實施，但尚未在您的賬戶上對其進行配置。請繼續設置雙重認證。",
    "Set up two-factor authentication" : "設定雙重認證",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "雙重認證已實施，但尚未在您的賬戶上對其進行配置。請使用一個備用驗證碼來登入或聯絡管理員。",
    "Use backup code" : "使用備用認證碼",
    "Cancel login" : "取消登入",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的賬號已啟用進階安全機制，請選擇一個供應者：",
    "Error while validating your second factor" : "驗證二階段因子發生錯誤",
    "Access through untrusted domain" : "經由不可信任的域名存取。",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "請聯絡您的管理員。如果您就是管理員，請模仿 config.sample.php 範例編輯 config/config.php 的「trusted_domains」設定。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "更多關於如何設定的資訊，請見%1$s文件%2$s。",
    "App update required" : "需要更新應用程式",
    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
    "The following apps will be updated:" : "將更新以下的 APP：",
    "These incompatible apps will be disabled:" : "以下不兼容的應用程式將被停用：",
    "The theme %s has been disabled." : "主題 %s 已經被停用。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
    "Start update" : "開始升級",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄執行以下指令：",
    "Detailed logs" : "詳細記錄檔",
    "Update needed" : "需要更新",
    "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過50名用戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
    "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
    "Maintenance mode" : "維護模式",
    "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，可能需要一段時間才能完成。",
    "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
    "[%d / %d]: Checking table %s" : "[%d / %d]： 檢查數據表 %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "此伺服器沒有網際網路連線（無法與多個端點取得聯繫），有些功能，例如外部儲存、應用程式更新版通知等等將無法運作。從遠端存取資料或是寄送通知電郵可能也無法運作。建議您設定好網際網路連線以使用所有功能。",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 是支援 PHP 7.2 的最後版本，Nextcloud 21 僅支援 PHP 7.3 以上的版本。",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "未加載 PHP OPcache 模塊。{linkstart}為獲得更佳性能，建議↗{linked}將其加載到您的 PHP 安裝中。",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache 模塊未正確配置。{linkstart}為獲得更佳性能，建議↗{linkend}在 <code>php.ini</code> 中使用以下設定：",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "數據庫中的某些列缺少對 big int 的轉換。由於更改大表上的列類型可能需要一些時間，因此無法自動更改它們。通過運行 “occ db：convert-filecache-bigint”，可以手動應用這些未決的更改。實例處於脫機狀態時需要執行此操作。有關更多詳細信息，請{linklink}關於此↗{linkend}的文檔頁面。",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "要遷移到另一個數據庫，請使用指令工具：“ occ db：convert-type”，或參閱 {linkstart} 說明書↗{linkend}。",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取，這表示 。htaccess 設定檔並未生效，我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
    "More" : "更多",
    "More apps menu" : "更多應用程式選單",
    "Settings menu" : "設定選單",
    "The password is wrong. Try again." : "密碼錯誤，請重試",
    "Setup two-factor authentication" : "設定雙重認證",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被停用，以避免我們的免費服務負載過重。請至 nextcloud.com/enterprise 取得更多關於 Nextcloud 企業版的資訊。",
    "You haven't added any info yet" : "您尚未新增任何資訊",
    "{user} hasn't added any info yet" : "{user} 尚未新增任何資訊"
},
"nplurals=1; plural=0;");
